@@ -26,7 +26,6 @@ DEFAULT_CONFIG = {"enabled": False}
 
 
 class CommonService:
-
     _daemon = {}
 
     def __init__(self, hook=None):
@@ -380,7 +379,6 @@ class JsOrc:
             return e
 
     def check(self, namespace, svc_name, hook):
-
         svc = self.meta.get_service(svc_name, hook)
 
         if not svc.is_running():
@@ -455,7 +453,6 @@ class JsOrc:
         self.services[name] = svc
 
     def build_service(self, name, background, *args, **kwargs):
-
         svc = self.services.get(name)
 
         if not svc:
@@ -491,11 +488,11 @@ class JsOrc:
     ###################################################
     #                 ACTION MANAGER                  #
     ###################################################
-    def load_action_config(self, name, config_mod):
+    def load_action_config(self, config, name):
         """
         Load the config for an action
         """
-        return load_action_config(config_mod, name)
+        return load_action_config(config, name)
 
     def load_actions(self, name, mode):
         """
